import { literal } from 'pg-format';
import { coalesceRowsToArray, filterByList } from './helpers.js';
import { columnsSql, foreignTablesSql } from './sql/index.js';
export default class PostgresMetaForeignTables {
    query;
    constructor(query) {
        this.query = query;
    }
    async list({ includedSchemas, excludedSchemas, limit, offset, includeColumns = true, } = {}) {
        let sql = generateEnrichedForeignTablesSql({ includeColumns });
        const filter = filterByList(includedSchemas, excludedSchemas);
        if (filter) {
            sql += ` where schema ${filter}`;
        }
        if (limit) {
            sql += ` limit ${limit}`;
        }
        if (offset) {
            sql += ` offset ${offset}`;
        }
        return await this.query(sql);
    }
    async retrieve({ id, name, schema = 'public', }) {
        if (id) {
            const sql = `${generateEnrichedForeignTablesSql({
                includeColumns: true,
            })} where foreign_tables.id = ${literal(id)};`;
            const { data, error } = await this.query(sql);
            if (error) {
                return { data, error };
            }
            else if (data.length === 0) {
                return { data: null, error: { message: `Cannot find a foreign table with ID ${id}` } };
            }
            else {
                return { data: data[0], error };
            }
        }
        else if (name) {
            const sql = `${generateEnrichedForeignTablesSql({
                includeColumns: true,
            })} where foreign_tables.name = ${literal(name)} and foreign_tables.schema = ${literal(schema)};`;
            const { data, error } = await this.query(sql);
            if (error) {
                return { data, error };
            }
            else if (data.length === 0) {
                return {
                    data: null,
                    error: { message: `Cannot find a foreign table named ${name} in schema ${schema}` },
                };
            }
            else {
                return { data: data[0], error };
            }
        }
        else {
            return { data: null, error: { message: 'Invalid parameters on foreign table retrieve' } };
        }
    }
}
const generateEnrichedForeignTablesSql = ({ includeColumns }) => `
with foreign_tables as (${foreignTablesSql})
  ${includeColumns ? `, columns as (${columnsSql})` : ''}
select
  *
  ${includeColumns
    ? `, ${coalesceRowsToArray('columns', 'columns.table_id = foreign_tables.id')}`
    : ''}
from foreign_tables`;
//# sourceMappingURL=PostgresMetaForeignTables.js.map