import { literal } from 'pg-format';
import { DEFAULT_SYSTEM_SCHEMAS } from './constants.js';
import { filterByList } from './helpers.js';
import { indexesSql } from './sql/index.js';
export default class PostgresMetaFunctions {
    query;
    constructor(query) {
        this.query = query;
    }
    async list({ includeSystemSchemas = false, includedSchemas, excludedSchemas, limit, offset, } = {}) {
        let sql = enrichedSql;
        const filter = filterByList(includedSchemas, excludedSchemas, !includeSystemSchemas ? DEFAULT_SYSTEM_SCHEMAS : undefined);
        if (filter) {
            sql += ` WHERE schema ${filter}`;
        }
        if (limit) {
            sql = `${sql} LIMIT ${limit}`;
        }
        if (offset) {
            sql = `${sql} OFFSET ${offset}`;
        }
        return await this.query(sql);
    }
    async retrieve({ id, args = [], }) {
        if (id) {
            const sql = `${enrichedSql} WHERE id = ${literal(id)};`;
            const { data, error } = await this.query(sql);
            if (error) {
                return { data, error };
            }
            else if (data.length === 0) {
                return { data: null, error: { message: `Cannot find a index with ID ${id}` } };
            }
            else {
                return { data: data[0], error };
            }
        }
        else {
            return { data: null, error: { message: 'Invalid parameters on function retrieve' } };
        }
    }
}
const enrichedSql = `
  WITH x AS (
    ${indexesSql}
  )
  SELECT
    x.*
  FROM x
`;
//# sourceMappingURL=PostgresMetaIndexes.js.map