import { Static } from '@sinclair/typebox';
import { DatabaseError } from 'pg-protocol';
import type { Options as PrettierOptions } from 'prettier';
import { PoolConfig as PgPoolConfig } from 'pg';
export interface FormatterOptions extends PrettierOptions {
}
export interface PostgresMetaOk<T> {
    data: T;
    error: null;
}
export interface PostgresMetaErr {
    data: null;
    error: Partial<DatabaseError> & {
        message: string;
        formattedError?: string;
    };
}
export type PostgresMetaResult<T> = PostgresMetaOk<T> | PostgresMetaErr;
export declare const postgresColumnSchema: import("@sinclair/typebox").TObject<{
    table_id: import("@sinclair/typebox").TInteger;
    schema: import("@sinclair/typebox").TString;
    table: import("@sinclair/typebox").TString;
    id: import("@sinclair/typebox").TString;
    ordinal_position: import("@sinclair/typebox").TInteger;
    name: import("@sinclair/typebox").TString;
    default_value: import("@sinclair/typebox").TUnknown;
    data_type: import("@sinclair/typebox").TString;
    format: import("@sinclair/typebox").TString;
    is_identity: import("@sinclair/typebox").TBoolean;
    identity_generation: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"ALWAYS">, import("@sinclair/typebox").TLiteral<"BY DEFAULT">, import("@sinclair/typebox").TNull]>;
    is_generated: import("@sinclair/typebox").TBoolean;
    is_nullable: import("@sinclair/typebox").TBoolean;
    is_updatable: import("@sinclair/typebox").TBoolean;
    is_unique: import("@sinclair/typebox").TBoolean;
    enums: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>;
    check: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    comment: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
}>;
export type PostgresColumn = Static<typeof postgresColumnSchema>;
export declare const postgresColumnCreateSchema: import("@sinclair/typebox").TObject<{
    table_id: import("@sinclair/typebox").TInteger;
    name: import("@sinclair/typebox").TString;
    type: import("@sinclair/typebox").TString;
    default_value: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TUnknown>;
    default_value_format: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"expression">, import("@sinclair/typebox").TLiteral<"literal">]>>;
    is_identity: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    identity_generation: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"BY DEFAULT">, import("@sinclair/typebox").TLiteral<"ALWAYS">]>>;
    is_nullable: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    is_primary_key: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    is_unique: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    comment: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    check: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
}>;
export type PostgresColumnCreate = Static<typeof postgresColumnCreateSchema>;
export declare const postgresColumnUpdateSchema: import("@sinclair/typebox").TObject<{
    name: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    type: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    drop_default: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    default_value: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TUnknown>;
    default_value_format: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"expression">, import("@sinclair/typebox").TLiteral<"literal">]>>;
    is_identity: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    identity_generation: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"BY DEFAULT">, import("@sinclair/typebox").TLiteral<"ALWAYS">]>>;
    is_nullable: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    is_unique: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    comment: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    check: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TNull, import("@sinclair/typebox").TString]>>;
}>;
export type PostgresColumnUpdate = Static<typeof postgresColumnUpdateSchema>;
export declare const postgresConfigSchema: import("@sinclair/typebox").TObject<{
    name: import("@sinclair/typebox").TUnknown;
    setting: import("@sinclair/typebox").TUnknown;
    category: import("@sinclair/typebox").TUnknown;
    group: import("@sinclair/typebox").TUnknown;
    subgroup: import("@sinclair/typebox").TUnknown;
    unit: import("@sinclair/typebox").TUnknown;
    short_desc: import("@sinclair/typebox").TUnknown;
    extra_desc: import("@sinclair/typebox").TUnknown;
    context: import("@sinclair/typebox").TUnknown;
    vartype: import("@sinclair/typebox").TUnknown;
    source: import("@sinclair/typebox").TUnknown;
    min_val: import("@sinclair/typebox").TUnknown;
    max_val: import("@sinclair/typebox").TUnknown;
    enumvals: import("@sinclair/typebox").TUnknown;
    boot_val: import("@sinclair/typebox").TUnknown;
    reset_val: import("@sinclair/typebox").TUnknown;
    sourcefile: import("@sinclair/typebox").TUnknown;
    sourceline: import("@sinclair/typebox").TUnknown;
    pending_restart: import("@sinclair/typebox").TUnknown;
}>;
export type PostgresConfig = Static<typeof postgresConfigSchema>;
export declare const postgresExtensionSchema: import("@sinclair/typebox").TObject<{
    name: import("@sinclair/typebox").TString;
    schema: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    default_version: import("@sinclair/typebox").TString;
    installed_version: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    comment: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
}>;
export type PostgresExtension = Static<typeof postgresExtensionSchema>;
export declare const postgresForeignTableSchema: import("@sinclair/typebox").TObject<{
    id: import("@sinclair/typebox").TInteger;
    schema: import("@sinclair/typebox").TString;
    name: import("@sinclair/typebox").TString;
    comment: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    columns: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        table_id: import("@sinclair/typebox").TInteger;
        schema: import("@sinclair/typebox").TString;
        table: import("@sinclair/typebox").TString;
        id: import("@sinclair/typebox").TString;
        ordinal_position: import("@sinclair/typebox").TInteger;
        name: import("@sinclair/typebox").TString;
        default_value: import("@sinclair/typebox").TUnknown;
        data_type: import("@sinclair/typebox").TString;
        format: import("@sinclair/typebox").TString;
        is_identity: import("@sinclair/typebox").TBoolean;
        identity_generation: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"ALWAYS">, import("@sinclair/typebox").TLiteral<"BY DEFAULT">, import("@sinclair/typebox").TNull]>;
        is_generated: import("@sinclair/typebox").TBoolean;
        is_nullable: import("@sinclair/typebox").TBoolean;
        is_updatable: import("@sinclair/typebox").TBoolean;
        is_unique: import("@sinclair/typebox").TBoolean;
        enums: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>;
        check: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
        comment: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    }>>>;
}>;
export type PostgresForeignTable = Static<typeof postgresForeignTableSchema>;
declare const postgresFunctionSchema: import("@sinclair/typebox").TObject<{
    id: import("@sinclair/typebox").TInteger;
    schema: import("@sinclair/typebox").TString;
    name: import("@sinclair/typebox").TString;
    language: import("@sinclair/typebox").TString;
    definition: import("@sinclair/typebox").TString;
    complete_statement: import("@sinclair/typebox").TString;
    args: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        mode: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"in">, import("@sinclair/typebox").TLiteral<"out">, import("@sinclair/typebox").TLiteral<"inout">, import("@sinclair/typebox").TLiteral<"variadic">, import("@sinclair/typebox").TLiteral<"table">]>;
        name: import("@sinclair/typebox").TString;
        type_id: import("@sinclair/typebox").TNumber;
        has_default: import("@sinclair/typebox").TBoolean;
    }>>;
    argument_types: import("@sinclair/typebox").TString;
    identity_argument_types: import("@sinclair/typebox").TString;
    return_type_id: import("@sinclair/typebox").TInteger;
    return_type: import("@sinclair/typebox").TString;
    return_type_relation_id: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TInteger, import("@sinclair/typebox").TNull]>;
    is_set_returning_function: import("@sinclair/typebox").TBoolean;
    behavior: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"IMMUTABLE">, import("@sinclair/typebox").TLiteral<"STABLE">, import("@sinclair/typebox").TLiteral<"VOLATILE">]>;
    security_definer: import("@sinclair/typebox").TBoolean;
    config_params: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TRecord<import("@sinclair/typebox").TString, import("@sinclair/typebox").TString>, import("@sinclair/typebox").TNull]>;
}>;
export type PostgresFunction = Static<typeof postgresFunctionSchema>;
export declare const postgresFunctionCreateFunction: import("@sinclair/typebox").TObject<{
    name: import("@sinclair/typebox").TString;
    definition: import("@sinclair/typebox").TString;
    args: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>>;
    behavior: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"IMMUTABLE">, import("@sinclair/typebox").TLiteral<"STABLE">, import("@sinclair/typebox").TLiteral<"VOLATILE">]>>;
    config_params: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TRecord<import("@sinclair/typebox").TString, import("@sinclair/typebox").TString>>;
    schema: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    language: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    return_type: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    security_definer: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
}>;
export type PostgresFunctionCreate = Static<typeof postgresFunctionCreateFunction>;
declare const postgresIndexSchema: import("@sinclair/typebox").TObject<{
    id: import("@sinclair/typebox").TInteger;
    table_id: import("@sinclair/typebox").TInteger;
    schema: import("@sinclair/typebox").TString;
    number_of_attributes: import("@sinclair/typebox").TInteger;
    number_of_key_attributes: import("@sinclair/typebox").TInteger;
    is_unique: import("@sinclair/typebox").TBoolean;
    is_primary: import("@sinclair/typebox").TBoolean;
    is_exclusion: import("@sinclair/typebox").TBoolean;
    is_immediate: import("@sinclair/typebox").TBoolean;
    is_clustered: import("@sinclair/typebox").TBoolean;
    is_valid: import("@sinclair/typebox").TBoolean;
    check_xmin: import("@sinclair/typebox").TBoolean;
    is_ready: import("@sinclair/typebox").TBoolean;
    is_live: import("@sinclair/typebox").TBoolean;
    is_replica_identity: import("@sinclair/typebox").TBoolean;
    key_attributes: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TNumber>;
    collation: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TNumber>;
    class: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TNumber>;
    options: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TNumber>;
    index_predicate: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    comment: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    index_definition: import("@sinclair/typebox").TString;
    access_method: import("@sinclair/typebox").TString;
    index_attributes: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        attribute_number: import("@sinclair/typebox").TNumber;
        attribute_name: import("@sinclair/typebox").TString;
        data_type: import("@sinclair/typebox").TString;
    }>>;
}>;
export type PostgresIndex = Static<typeof postgresIndexSchema>;
export declare const postgresPolicySchema: import("@sinclair/typebox").TObject<{
    id: import("@sinclair/typebox").TInteger;
    schema: import("@sinclair/typebox").TString;
    table: import("@sinclair/typebox").TString;
    table_id: import("@sinclair/typebox").TInteger;
    name: import("@sinclair/typebox").TString;
    action: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"PERMISSIVE">, import("@sinclair/typebox").TLiteral<"RESTRICTIVE">]>;
    roles: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>;
    command: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"SELECT">, import("@sinclair/typebox").TLiteral<"INSERT">, import("@sinclair/typebox").TLiteral<"UPDATE">, import("@sinclair/typebox").TLiteral<"DELETE">, import("@sinclair/typebox").TLiteral<"ALL">]>;
    definition: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    check: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
}>;
export type PostgresPolicy = Static<typeof postgresPolicySchema>;
export declare const postgresPrimaryKeySchema: import("@sinclair/typebox").TObject<{
    schema: import("@sinclair/typebox").TString;
    table_name: import("@sinclair/typebox").TString;
    name: import("@sinclair/typebox").TString;
    table_id: import("@sinclair/typebox").TInteger;
}>;
export type PostgresPrimaryKey = Static<typeof postgresPrimaryKeySchema>;
export declare const postgresPublicationSchema: import("@sinclair/typebox").TObject<{
    id: import("@sinclair/typebox").TInteger;
    name: import("@sinclair/typebox").TString;
    owner: import("@sinclair/typebox").TString;
    publish_insert: import("@sinclair/typebox").TBoolean;
    publish_update: import("@sinclair/typebox").TBoolean;
    publish_delete: import("@sinclair/typebox").TBoolean;
    publish_truncate: import("@sinclair/typebox").TBoolean;
    tables: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        id: import("@sinclair/typebox").TInteger;
        name: import("@sinclair/typebox").TString;
        schema: import("@sinclair/typebox").TString;
    }>>, import("@sinclair/typebox").TNull]>;
}>;
export type PostgresPublication = Static<typeof postgresPublicationSchema>;
export declare const postgresRelationshipOldSchema: import("@sinclair/typebox").TObject<{
    id: import("@sinclair/typebox").TInteger;
    constraint_name: import("@sinclair/typebox").TString;
    source_schema: import("@sinclair/typebox").TString;
    source_table_name: import("@sinclair/typebox").TString;
    source_column_name: import("@sinclair/typebox").TString;
    target_table_schema: import("@sinclair/typebox").TString;
    target_table_name: import("@sinclair/typebox").TString;
    target_column_name: import("@sinclair/typebox").TString;
}>;
export declare const postgresRelationshipSchema: import("@sinclair/typebox").TObject<{
    foreign_key_name: import("@sinclair/typebox").TString;
    schema: import("@sinclair/typebox").TString;
    relation: import("@sinclair/typebox").TString;
    columns: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>;
    is_one_to_one: import("@sinclair/typebox").TBoolean;
    referenced_schema: import("@sinclair/typebox").TString;
    referenced_relation: import("@sinclair/typebox").TString;
    referenced_columns: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>;
}>;
export type PostgresRelationship = Static<typeof postgresRelationshipSchema>;
export declare const PostgresMetaRoleConfigSchema: import("@sinclair/typebox").TObject<{
    op: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"remove">, import("@sinclair/typebox").TLiteral<"add">, import("@sinclair/typebox").TLiteral<"replace">]>;
    path: import("@sinclair/typebox").TString;
    value: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
}>;
export type PostgresMetaRoleConfig = Static<typeof PostgresMetaRoleConfigSchema>;
export declare const postgresRoleSchema: import("@sinclair/typebox").TObject<{
    id: import("@sinclair/typebox").TInteger;
    name: import("@sinclair/typebox").TString;
    is_superuser: import("@sinclair/typebox").TBoolean;
    can_create_db: import("@sinclair/typebox").TBoolean;
    can_create_role: import("@sinclair/typebox").TBoolean;
    inherit_role: import("@sinclair/typebox").TBoolean;
    can_login: import("@sinclair/typebox").TBoolean;
    is_replication_role: import("@sinclair/typebox").TBoolean;
    can_bypass_rls: import("@sinclair/typebox").TBoolean;
    active_connections: import("@sinclair/typebox").TInteger;
    connection_limit: import("@sinclair/typebox").TInteger;
    password: import("@sinclair/typebox").TString;
    valid_until: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    config: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull, import("@sinclair/typebox").TRecord<import("@sinclair/typebox").TString, import("@sinclair/typebox").TString>]>;
}>;
export type PostgresRole = Static<typeof postgresRoleSchema>;
export declare const postgresRoleCreateSchema: import("@sinclair/typebox").TObject<{
    name: import("@sinclair/typebox").TString;
    password: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    inherit_role: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    can_login: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    is_superuser: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    can_create_db: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    can_create_role: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    is_replication_role: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    can_bypass_rls: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    connection_limit: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TInteger>;
    member_of: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>>;
    members: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>>;
    admins: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>>;
    valid_until: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    config: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TRecord<import("@sinclair/typebox").TString, import("@sinclair/typebox").TString>>;
}>;
export type PostgresRoleCreate = Static<typeof postgresRoleCreateSchema>;
export declare const postgresRoleUpdateSchema: import("@sinclair/typebox").TObject<{
    name: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    password: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    inherit_role: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    can_login: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    is_superuser: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    can_create_db: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    can_create_role: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    is_replication_role: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    can_bypass_rls: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    connection_limit: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TInteger>;
    valid_until: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    config: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        op: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"remove">, import("@sinclair/typebox").TLiteral<"add">, import("@sinclair/typebox").TLiteral<"replace">]>;
        path: import("@sinclair/typebox").TString;
        value: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    }>>>;
}>;
export type PostgresRoleUpdate = Static<typeof postgresRoleUpdateSchema>;
export declare const postgresSchemaSchema: import("@sinclair/typebox").TObject<{
    id: import("@sinclair/typebox").TInteger;
    name: import("@sinclair/typebox").TString;
    owner: import("@sinclair/typebox").TString;
}>;
export type PostgresSchema = Static<typeof postgresSchemaSchema>;
export declare const postgresSchemaCreateSchema: import("@sinclair/typebox").TObject<{
    name: import("@sinclair/typebox").TString;
    owner: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
}>;
export type PostgresSchemaCreate = Static<typeof postgresSchemaCreateSchema>;
export declare const postgresSchemaUpdateSchema: import("@sinclair/typebox").TObject<{
    name: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    owner: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
}>;
export type PostgresSchemaUpdate = Static<typeof postgresSchemaUpdateSchema>;
export declare const postgresTableSchema: import("@sinclair/typebox").TObject<{
    id: import("@sinclair/typebox").TInteger;
    schema: import("@sinclair/typebox").TString;
    name: import("@sinclair/typebox").TString;
    rls_enabled: import("@sinclair/typebox").TBoolean;
    rls_forced: import("@sinclair/typebox").TBoolean;
    replica_identity: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"DEFAULT">, import("@sinclair/typebox").TLiteral<"INDEX">, import("@sinclair/typebox").TLiteral<"FULL">, import("@sinclair/typebox").TLiteral<"NOTHING">]>;
    bytes: import("@sinclair/typebox").TInteger;
    size: import("@sinclair/typebox").TString;
    live_rows_estimate: import("@sinclair/typebox").TInteger;
    dead_rows_estimate: import("@sinclair/typebox").TInteger;
    comment: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    columns: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        table_id: import("@sinclair/typebox").TInteger;
        schema: import("@sinclair/typebox").TString;
        table: import("@sinclair/typebox").TString;
        id: import("@sinclair/typebox").TString;
        ordinal_position: import("@sinclair/typebox").TInteger;
        name: import("@sinclair/typebox").TString;
        default_value: import("@sinclair/typebox").TUnknown;
        data_type: import("@sinclair/typebox").TString;
        format: import("@sinclair/typebox").TString;
        is_identity: import("@sinclair/typebox").TBoolean;
        identity_generation: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"ALWAYS">, import("@sinclair/typebox").TLiteral<"BY DEFAULT">, import("@sinclair/typebox").TNull]>;
        is_generated: import("@sinclair/typebox").TBoolean;
        is_nullable: import("@sinclair/typebox").TBoolean;
        is_updatable: import("@sinclair/typebox").TBoolean;
        is_unique: import("@sinclair/typebox").TBoolean;
        enums: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>;
        check: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
        comment: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    }>>>;
    primary_keys: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        schema: import("@sinclair/typebox").TString;
        table_name: import("@sinclair/typebox").TString;
        name: import("@sinclair/typebox").TString;
        table_id: import("@sinclair/typebox").TInteger;
    }>>;
    relationships: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        id: import("@sinclair/typebox").TInteger;
        constraint_name: import("@sinclair/typebox").TString;
        source_schema: import("@sinclair/typebox").TString;
        source_table_name: import("@sinclair/typebox").TString;
        source_column_name: import("@sinclair/typebox").TString;
        target_table_schema: import("@sinclair/typebox").TString;
        target_table_name: import("@sinclair/typebox").TString;
        target_column_name: import("@sinclair/typebox").TString;
    }>>;
}>;
export type PostgresTable = Static<typeof postgresTableSchema>;
export declare const postgresTableCreateSchema: import("@sinclair/typebox").TObject<{
    name: import("@sinclair/typebox").TString;
    schema: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    comment: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
}>;
export type PostgresTableCreate = Static<typeof postgresTableCreateSchema>;
export declare const postgresTableUpdateSchema: import("@sinclair/typebox").TObject<{
    name: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    schema: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    rls_enabled: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    rls_forced: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
    replica_identity: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"DEFAULT">, import("@sinclair/typebox").TLiteral<"INDEX">, import("@sinclair/typebox").TLiteral<"FULL">, import("@sinclair/typebox").TLiteral<"NOTHING">]>>;
    replica_identity_index: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
    primary_keys: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        name: import("@sinclair/typebox").TString;
    }>>>;
    comment: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TString>;
}>;
export type PostgresTableUpdate = Static<typeof postgresTableUpdateSchema>;
export declare const postgresTriggerSchema: import("@sinclair/typebox").TObject<{
    id: import("@sinclair/typebox").TInteger;
    table_id: import("@sinclair/typebox").TInteger;
    enabled_mode: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"ORIGIN">, import("@sinclair/typebox").TLiteral<"REPLICA">, import("@sinclair/typebox").TLiteral<"ALWAYS">, import("@sinclair/typebox").TLiteral<"DISABLED">]>;
    name: import("@sinclair/typebox").TString;
    table: import("@sinclair/typebox").TString;
    schema: import("@sinclair/typebox").TString;
    condition: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    orientation: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"ROW">, import("@sinclair/typebox").TLiteral<"STATEMENT">]>;
    activation: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"BEFORE">, import("@sinclair/typebox").TLiteral<"AFTER">, import("@sinclair/typebox").TLiteral<"INSTEAD OF">]>;
    events: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>;
    function_schema: import("@sinclair/typebox").TString;
    function_name: import("@sinclair/typebox").TString;
    function_args: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>;
}>;
export type PostgresTrigger = Static<typeof postgresTriggerSchema>;
export declare const postgresTypeSchema: import("@sinclair/typebox").TObject<{
    id: import("@sinclair/typebox").TInteger;
    name: import("@sinclair/typebox").TString;
    schema: import("@sinclair/typebox").TString;
    format: import("@sinclair/typebox").TString;
    enums: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>;
    attributes: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        name: import("@sinclair/typebox").TString;
        type_id: import("@sinclair/typebox").TInteger;
    }>>;
    comment: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
}>;
export type PostgresType = Static<typeof postgresTypeSchema>;
export declare const postgresVersionSchema: import("@sinclair/typebox").TObject<{
    version: import("@sinclair/typebox").TString;
    version_number: import("@sinclair/typebox").TInteger;
    active_connections: import("@sinclair/typebox").TInteger;
    max_connections: import("@sinclair/typebox").TInteger;
}>;
export type PostgresVersion = Static<typeof postgresVersionSchema>;
export declare const postgresViewSchema: import("@sinclair/typebox").TObject<{
    id: import("@sinclair/typebox").TInteger;
    schema: import("@sinclair/typebox").TString;
    name: import("@sinclair/typebox").TString;
    is_updatable: import("@sinclair/typebox").TBoolean;
    comment: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    columns: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        table_id: import("@sinclair/typebox").TInteger;
        schema: import("@sinclair/typebox").TString;
        table: import("@sinclair/typebox").TString;
        id: import("@sinclair/typebox").TString;
        ordinal_position: import("@sinclair/typebox").TInteger;
        name: import("@sinclair/typebox").TString;
        default_value: import("@sinclair/typebox").TUnknown;
        data_type: import("@sinclair/typebox").TString;
        format: import("@sinclair/typebox").TString;
        is_identity: import("@sinclair/typebox").TBoolean;
        identity_generation: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"ALWAYS">, import("@sinclair/typebox").TLiteral<"BY DEFAULT">, import("@sinclair/typebox").TNull]>;
        is_generated: import("@sinclair/typebox").TBoolean;
        is_nullable: import("@sinclair/typebox").TBoolean;
        is_updatable: import("@sinclair/typebox").TBoolean;
        is_unique: import("@sinclair/typebox").TBoolean;
        enums: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>;
        check: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
        comment: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    }>>>;
}>;
export type PostgresView = Static<typeof postgresViewSchema>;
export declare const postgresMaterializedViewSchema: import("@sinclair/typebox").TObject<{
    id: import("@sinclair/typebox").TInteger;
    schema: import("@sinclair/typebox").TString;
    name: import("@sinclair/typebox").TString;
    is_populated: import("@sinclair/typebox").TBoolean;
    comment: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    columns: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        table_id: import("@sinclair/typebox").TInteger;
        schema: import("@sinclair/typebox").TString;
        table: import("@sinclair/typebox").TString;
        id: import("@sinclair/typebox").TString;
        ordinal_position: import("@sinclair/typebox").TInteger;
        name: import("@sinclair/typebox").TString;
        default_value: import("@sinclair/typebox").TUnknown;
        data_type: import("@sinclair/typebox").TString;
        format: import("@sinclair/typebox").TString;
        is_identity: import("@sinclair/typebox").TBoolean;
        identity_generation: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"ALWAYS">, import("@sinclair/typebox").TLiteral<"BY DEFAULT">, import("@sinclair/typebox").TNull]>;
        is_generated: import("@sinclair/typebox").TBoolean;
        is_nullable: import("@sinclair/typebox").TBoolean;
        is_updatable: import("@sinclair/typebox").TBoolean;
        is_unique: import("@sinclair/typebox").TBoolean;
        enums: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TString>;
        check: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
        comment: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TString, import("@sinclair/typebox").TNull]>;
    }>>>;
}>;
export type PostgresMaterializedView = Static<typeof postgresMaterializedViewSchema>;
export declare const postgresTablePrivilegesSchema: import("@sinclair/typebox").TObject<{
    relation_id: import("@sinclair/typebox").TInteger;
    schema: import("@sinclair/typebox").TString;
    name: import("@sinclair/typebox").TString;
    kind: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"table">, import("@sinclair/typebox").TLiteral<"view">, import("@sinclair/typebox").TLiteral<"materialized_view">, import("@sinclair/typebox").TLiteral<"foreign_table">, import("@sinclair/typebox").TLiteral<"partitioned_table">]>;
    privileges: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        grantor: import("@sinclair/typebox").TString;
        grantee: import("@sinclair/typebox").TString;
        privilege_type: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"SELECT">, import("@sinclair/typebox").TLiteral<"INSERT">, import("@sinclair/typebox").TLiteral<"UPDATE">, import("@sinclair/typebox").TLiteral<"DELETE">, import("@sinclair/typebox").TLiteral<"TRUNCATE">, import("@sinclair/typebox").TLiteral<"REFERENCES">, import("@sinclair/typebox").TLiteral<"TRIGGER">, import("@sinclair/typebox").TLiteral<"MAINTAIN">]>;
        is_grantable: import("@sinclair/typebox").TBoolean;
    }>>;
}>;
export type PostgresTablePrivileges = Static<typeof postgresTablePrivilegesSchema>;
export declare const postgresTablePrivilegesGrantSchema: import("@sinclair/typebox").TObject<{
    relation_id: import("@sinclair/typebox").TInteger;
    grantee: import("@sinclair/typebox").TString;
    privilege_type: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"ALL">, import("@sinclair/typebox").TLiteral<"SELECT">, import("@sinclair/typebox").TLiteral<"INSERT">, import("@sinclair/typebox").TLiteral<"UPDATE">, import("@sinclair/typebox").TLiteral<"DELETE">, import("@sinclair/typebox").TLiteral<"TRUNCATE">, import("@sinclair/typebox").TLiteral<"REFERENCES">, import("@sinclair/typebox").TLiteral<"TRIGGER">, import("@sinclair/typebox").TLiteral<"MAINTAIN">]>;
    is_grantable: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
}>;
export type PostgresTablePrivilegesGrant = Static<typeof postgresTablePrivilegesGrantSchema>;
export declare const postgresTablePrivilegesRevokeSchema: import("@sinclair/typebox").TObject<{
    relation_id: import("@sinclair/typebox").TInteger;
    grantee: import("@sinclair/typebox").TString;
    privilege_type: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"ALL">, import("@sinclair/typebox").TLiteral<"SELECT">, import("@sinclair/typebox").TLiteral<"INSERT">, import("@sinclair/typebox").TLiteral<"UPDATE">, import("@sinclair/typebox").TLiteral<"DELETE">, import("@sinclair/typebox").TLiteral<"TRUNCATE">, import("@sinclair/typebox").TLiteral<"REFERENCES">, import("@sinclair/typebox").TLiteral<"TRIGGER">, import("@sinclair/typebox").TLiteral<"MAINTAIN">]>;
}>;
export type PostgresTablePrivilegesRevoke = Static<typeof postgresTablePrivilegesRevokeSchema>;
export declare const postgresColumnPrivilegesSchema: import("@sinclair/typebox").TObject<{
    column_id: import("@sinclair/typebox").TString;
    relation_schema: import("@sinclair/typebox").TString;
    relation_name: import("@sinclair/typebox").TString;
    column_name: import("@sinclair/typebox").TString;
    privileges: import("@sinclair/typebox").TArray<import("@sinclair/typebox").TObject<{
        grantor: import("@sinclair/typebox").TString;
        grantee: import("@sinclair/typebox").TString;
        privilege_type: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"SELECT">, import("@sinclair/typebox").TLiteral<"INSERT">, import("@sinclair/typebox").TLiteral<"UPDATE">, import("@sinclair/typebox").TLiteral<"REFERENCES">]>;
        is_grantable: import("@sinclair/typebox").TBoolean;
    }>>;
}>;
export type PostgresColumnPrivileges = Static<typeof postgresColumnPrivilegesSchema>;
export declare const postgresColumnPrivilegesGrantSchema: import("@sinclair/typebox").TObject<{
    column_id: import("@sinclair/typebox").TString;
    grantee: import("@sinclair/typebox").TString;
    privilege_type: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"ALL">, import("@sinclair/typebox").TLiteral<"SELECT">, import("@sinclair/typebox").TLiteral<"INSERT">, import("@sinclair/typebox").TLiteral<"UPDATE">, import("@sinclair/typebox").TLiteral<"REFERENCES">]>;
    is_grantable: import("@sinclair/typebox").TOptional<import("@sinclair/typebox").TBoolean>;
}>;
export type PostgresColumnPrivilegesGrant = Static<typeof postgresColumnPrivilegesGrantSchema>;
export declare const postgresColumnPrivilegesRevokeSchema: import("@sinclair/typebox").TObject<{
    column_id: import("@sinclair/typebox").TString;
    grantee: import("@sinclair/typebox").TString;
    privilege_type: import("@sinclair/typebox").TUnion<[import("@sinclair/typebox").TLiteral<"ALL">, import("@sinclair/typebox").TLiteral<"SELECT">, import("@sinclair/typebox").TLiteral<"INSERT">, import("@sinclair/typebox").TLiteral<"UPDATE">, import("@sinclair/typebox").TLiteral<"REFERENCES">]>;
}>;
export type PostgresColumnPrivilegesRevoke = Static<typeof postgresColumnPrivilegesRevokeSchema>;
export interface PoolConfig extends PgPoolConfig {
    maxResultSize?: number;
}
export {};
//# sourceMappingURL=types.d.ts.map