import { Type } from '@sinclair/typebox';
export const postgresColumnSchema = Type.Object({
    table_id: Type.Integer(),
    schema: Type.String(),
    table: Type.String(),
    id: Type.RegExp(/^(\d+)\.(\d+)$/),
    ordinal_position: Type.Integer(),
    name: Type.String(),
    default_value: Type.Unknown(),
    data_type: Type.String(),
    format: Type.String(),
    is_identity: Type.Boolean(),
    identity_generation: Type.Union([
        Type.Literal('ALWAYS'),
        Type.Literal('BY DEFAULT'),
        Type.Null(),
    ]),
    is_generated: Type.Boolean(),
    is_nullable: Type.Boolean(),
    is_updatable: Type.Boolean(),
    is_unique: Type.Boolean(),
    enums: Type.Array(Type.String()),
    check: Type.Union([Type.String(), Type.Null()]),
    comment: Type.Union([Type.String(), Type.Null()]),
});
export const postgresColumnCreateSchema = Type.Object({
    table_id: Type.Integer(),
    name: Type.String(),
    type: Type.String(),
    default_value: Type.Optional(Type.Unknown()),
    default_value_format: Type.Optional(Type.Union([Type.Literal('expression'), Type.Literal('literal')])),
    is_identity: Type.Optional(Type.Boolean()),
    identity_generation: Type.Optional(Type.Union([Type.Literal('BY DEFAULT'), Type.Literal('ALWAYS')])),
    is_nullable: Type.Optional(Type.Boolean()),
    is_primary_key: Type.Optional(Type.Boolean()),
    is_unique: Type.Optional(Type.Boolean()),
    comment: Type.Optional(Type.String()),
    check: Type.Optional(Type.String()),
});
export const postgresColumnUpdateSchema = Type.Object({
    name: Type.Optional(Type.String()),
    type: Type.Optional(Type.String()),
    drop_default: Type.Optional(Type.Boolean()),
    default_value: Type.Optional(Type.Unknown()),
    default_value_format: Type.Optional(Type.Union([Type.Literal('expression'), Type.Literal('literal')])),
    is_identity: Type.Optional(Type.Boolean()),
    identity_generation: Type.Optional(Type.Union([Type.Literal('BY DEFAULT'), Type.Literal('ALWAYS')])),
    is_nullable: Type.Optional(Type.Boolean()),
    is_unique: Type.Optional(Type.Boolean()),
    comment: Type.Optional(Type.String()),
    check: Type.Optional(Type.Union(
    // Type.Null() must go first: https://github.com/sinclairzx81/typebox/issues/546
    [Type.Null(), Type.String()])),
});
// TODO Rethink config.sql
export const postgresConfigSchema = Type.Object({
    name: Type.Unknown(),
    setting: Type.Unknown(),
    category: Type.Unknown(),
    group: Type.Unknown(),
    subgroup: Type.Unknown(),
    unit: Type.Unknown(),
    short_desc: Type.Unknown(),
    extra_desc: Type.Unknown(),
    context: Type.Unknown(),
    vartype: Type.Unknown(),
    source: Type.Unknown(),
    min_val: Type.Unknown(),
    max_val: Type.Unknown(),
    enumvals: Type.Unknown(),
    boot_val: Type.Unknown(),
    reset_val: Type.Unknown(),
    sourcefile: Type.Unknown(),
    sourceline: Type.Unknown(),
    pending_restart: Type.Unknown(),
});
export const postgresExtensionSchema = Type.Object({
    name: Type.String(),
    schema: Type.Union([Type.String(), Type.Null()]),
    default_version: Type.String(),
    installed_version: Type.Union([Type.String(), Type.Null()]),
    comment: Type.Union([Type.String(), Type.Null()]),
});
export const postgresForeignTableSchema = Type.Object({
    id: Type.Integer(),
    schema: Type.String(),
    name: Type.String(),
    comment: Type.Union([Type.String(), Type.Null()]),
    columns: Type.Optional(Type.Array(postgresColumnSchema)),
});
const postgresFunctionSchema = Type.Object({
    id: Type.Integer(),
    schema: Type.String(),
    name: Type.String(),
    language: Type.String(),
    definition: Type.String(),
    complete_statement: Type.String(),
    args: Type.Array(Type.Object({
        mode: Type.Union([
            Type.Literal('in'),
            Type.Literal('out'),
            Type.Literal('inout'),
            Type.Literal('variadic'),
            Type.Literal('table'),
        ]),
        name: Type.String(),
        type_id: Type.Number(),
        has_default: Type.Boolean(),
    })),
    argument_types: Type.String(),
    identity_argument_types: Type.String(),
    return_type_id: Type.Integer(),
    return_type: Type.String(),
    return_type_relation_id: Type.Union([Type.Integer(), Type.Null()]),
    is_set_returning_function: Type.Boolean(),
    behavior: Type.Union([
        Type.Literal('IMMUTABLE'),
        Type.Literal('STABLE'),
        Type.Literal('VOLATILE'),
    ]),
    security_definer: Type.Boolean(),
    config_params: Type.Union([Type.Record(Type.String(), Type.String()), Type.Null()]),
});
export const postgresFunctionCreateFunction = Type.Object({
    name: Type.String(),
    definition: Type.String(),
    args: Type.Optional(Type.Array(Type.String())),
    behavior: Type.Optional(Type.Union([Type.Literal('IMMUTABLE'), Type.Literal('STABLE'), Type.Literal('VOLATILE')])),
    config_params: Type.Optional(Type.Record(Type.String(), Type.String())),
    schema: Type.Optional(Type.String()),
    language: Type.Optional(Type.String()),
    return_type: Type.Optional(Type.String()),
    security_definer: Type.Optional(Type.Boolean()),
});
const postgresIndexSchema = Type.Object({
    id: Type.Integer(),
    table_id: Type.Integer(),
    schema: Type.String(),
    number_of_attributes: Type.Integer(),
    number_of_key_attributes: Type.Integer(),
    is_unique: Type.Boolean(),
    is_primary: Type.Boolean(),
    is_exclusion: Type.Boolean(),
    is_immediate: Type.Boolean(),
    is_clustered: Type.Boolean(),
    is_valid: Type.Boolean(),
    check_xmin: Type.Boolean(),
    is_ready: Type.Boolean(),
    is_live: Type.Boolean(),
    is_replica_identity: Type.Boolean(),
    key_attributes: Type.Array(Type.Number()),
    collation: Type.Array(Type.Number()),
    class: Type.Array(Type.Number()),
    options: Type.Array(Type.Number()),
    index_predicate: Type.Union([Type.String(), Type.Null()]),
    comment: Type.Union([Type.String(), Type.Null()]),
    index_definition: Type.String(),
    access_method: Type.String(),
    index_attributes: Type.Array(Type.Object({
        attribute_number: Type.Number(),
        attribute_name: Type.String(),
        data_type: Type.String(),
    })),
});
export const postgresPolicySchema = Type.Object({
    id: Type.Integer(),
    schema: Type.String(),
    table: Type.String(),
    table_id: Type.Integer(),
    name: Type.String(),
    action: Type.Union([Type.Literal('PERMISSIVE'), Type.Literal('RESTRICTIVE')]),
    roles: Type.Array(Type.String()),
    command: Type.Union([
        Type.Literal('SELECT'),
        Type.Literal('INSERT'),
        Type.Literal('UPDATE'),
        Type.Literal('DELETE'),
        Type.Literal('ALL'),
    ]),
    definition: Type.Union([Type.String(), Type.Null()]),
    check: Type.Union([Type.String(), Type.Null()]),
});
export const postgresPrimaryKeySchema = Type.Object({
    schema: Type.String(),
    table_name: Type.String(),
    name: Type.String(),
    table_id: Type.Integer(),
});
export const postgresPublicationSchema = Type.Object({
    id: Type.Integer(),
    name: Type.String(),
    owner: Type.String(),
    publish_insert: Type.Boolean(),
    publish_update: Type.Boolean(),
    publish_delete: Type.Boolean(),
    publish_truncate: Type.Boolean(),
    tables: Type.Union([
        Type.Array(Type.Object({ id: Type.Integer(), name: Type.String(), schema: Type.String() })),
        Type.Null(),
    ]),
});
export const postgresRelationshipOldSchema = Type.Object({
    id: Type.Integer(),
    constraint_name: Type.String(),
    source_schema: Type.String(),
    source_table_name: Type.String(),
    source_column_name: Type.String(),
    target_table_schema: Type.String(),
    target_table_name: Type.String(),
    target_column_name: Type.String(),
});
export const postgresRelationshipSchema = Type.Object({
    foreign_key_name: Type.String(),
    schema: Type.String(),
    relation: Type.String(),
    columns: Type.Array(Type.String()),
    is_one_to_one: Type.Boolean(),
    referenced_schema: Type.String(),
    referenced_relation: Type.String(),
    referenced_columns: Type.Array(Type.String()),
});
export const PostgresMetaRoleConfigSchema = Type.Object({
    op: Type.Union([Type.Literal('remove'), Type.Literal('add'), Type.Literal('replace')]),
    path: Type.String(),
    value: Type.Optional(Type.String()),
});
export const postgresRoleSchema = Type.Object({
    id: Type.Integer(),
    name: Type.String(),
    is_superuser: Type.Boolean(),
    can_create_db: Type.Boolean(),
    can_create_role: Type.Boolean(),
    inherit_role: Type.Boolean(),
    can_login: Type.Boolean(),
    is_replication_role: Type.Boolean(),
    can_bypass_rls: Type.Boolean(),
    active_connections: Type.Integer(),
    connection_limit: Type.Integer(),
    password: Type.String(),
    valid_until: Type.Union([Type.String(), Type.Null()]),
    config: Type.Union([Type.String(), Type.Null(), Type.Record(Type.String(), Type.String())]),
});
export const postgresRoleCreateSchema = Type.Object({
    name: Type.String(),
    password: Type.Optional(Type.String()),
    inherit_role: Type.Optional(Type.Boolean()),
    can_login: Type.Optional(Type.Boolean()),
    is_superuser: Type.Optional(Type.Boolean()),
    can_create_db: Type.Optional(Type.Boolean()),
    can_create_role: Type.Optional(Type.Boolean()),
    is_replication_role: Type.Optional(Type.Boolean()),
    can_bypass_rls: Type.Optional(Type.Boolean()),
    connection_limit: Type.Optional(Type.Integer()),
    member_of: Type.Optional(Type.Array(Type.String())),
    members: Type.Optional(Type.Array(Type.String())),
    admins: Type.Optional(Type.Array(Type.String())),
    valid_until: Type.Optional(Type.String()),
    config: Type.Optional(Type.Record(Type.String(), Type.String())),
});
export const postgresRoleUpdateSchema = Type.Object({
    name: Type.Optional(Type.String()),
    password: Type.Optional(Type.String()),
    inherit_role: Type.Optional(Type.Boolean()),
    can_login: Type.Optional(Type.Boolean()),
    is_superuser: Type.Optional(Type.Boolean()),
    can_create_db: Type.Optional(Type.Boolean()),
    can_create_role: Type.Optional(Type.Boolean()),
    is_replication_role: Type.Optional(Type.Boolean()),
    can_bypass_rls: Type.Optional(Type.Boolean()),
    connection_limit: Type.Optional(Type.Integer()),
    valid_until: Type.Optional(Type.String()),
    config: Type.Optional(Type.Array(PostgresMetaRoleConfigSchema)),
});
export const postgresSchemaSchema = Type.Object({
    id: Type.Integer(),
    name: Type.String(),
    owner: Type.String(),
});
export const postgresSchemaCreateSchema = Type.Object({
    name: Type.String(),
    owner: Type.Optional(Type.String()),
});
export const postgresSchemaUpdateSchema = Type.Object({
    name: Type.Optional(Type.String()),
    owner: Type.Optional(Type.String()),
});
export const postgresTableSchema = Type.Object({
    id: Type.Integer(),
    schema: Type.String(),
    name: Type.String(),
    rls_enabled: Type.Boolean(),
    rls_forced: Type.Boolean(),
    replica_identity: Type.Union([
        Type.Literal('DEFAULT'),
        Type.Literal('INDEX'),
        Type.Literal('FULL'),
        Type.Literal('NOTHING'),
    ]),
    bytes: Type.Integer(),
    size: Type.String(),
    live_rows_estimate: Type.Integer(),
    dead_rows_estimate: Type.Integer(),
    comment: Type.Union([Type.String(), Type.Null()]),
    columns: Type.Optional(Type.Array(postgresColumnSchema)),
    primary_keys: Type.Array(postgresPrimaryKeySchema),
    relationships: Type.Array(postgresRelationshipOldSchema),
});
export const postgresTableCreateSchema = Type.Object({
    name: Type.String(),
    schema: Type.Optional(Type.String()),
    comment: Type.Optional(Type.String()),
});
export const postgresTableUpdateSchema = Type.Object({
    name: Type.Optional(Type.String()),
    schema: Type.Optional(Type.String()),
    rls_enabled: Type.Optional(Type.Boolean()),
    rls_forced: Type.Optional(Type.Boolean()),
    replica_identity: Type.Optional(Type.Union([
        Type.Literal('DEFAULT'),
        Type.Literal('INDEX'),
        Type.Literal('FULL'),
        Type.Literal('NOTHING'),
    ])),
    replica_identity_index: Type.Optional(Type.String()),
    primary_keys: Type.Optional(Type.Array(Type.Object({ name: Type.String() }))),
    comment: Type.Optional(Type.String()),
});
export const postgresTriggerSchema = Type.Object({
    id: Type.Integer(),
    table_id: Type.Integer(),
    enabled_mode: Type.Union([
        Type.Literal('ORIGIN'),
        Type.Literal('REPLICA'),
        Type.Literal('ALWAYS'),
        Type.Literal('DISABLED'),
    ]),
    name: Type.String(),
    table: Type.String(),
    schema: Type.String(),
    condition: Type.Union([Type.String(), Type.Null()]),
    orientation: Type.Union([Type.Literal('ROW'), Type.Literal('STATEMENT')]),
    activation: Type.Union([
        Type.Literal('BEFORE'),
        Type.Literal('AFTER'),
        Type.Literal('INSTEAD OF'),
    ]),
    events: Type.Array(Type.String()),
    function_schema: Type.String(),
    function_name: Type.String(),
    function_args: Type.Array(Type.String()),
});
export const postgresTypeSchema = Type.Object({
    id: Type.Integer(),
    name: Type.String(),
    schema: Type.String(),
    format: Type.String(),
    enums: Type.Array(Type.String()),
    attributes: Type.Array(Type.Object({ name: Type.String(), type_id: Type.Integer() })),
    comment: Type.Union([Type.String(), Type.Null()]),
});
export const postgresVersionSchema = Type.Object({
    version: Type.String(),
    version_number: Type.Integer(),
    active_connections: Type.Integer(),
    max_connections: Type.Integer(),
});
export const postgresViewSchema = Type.Object({
    id: Type.Integer(),
    schema: Type.String(),
    name: Type.String(),
    is_updatable: Type.Boolean(),
    comment: Type.Union([Type.String(), Type.Null()]),
    columns: Type.Optional(Type.Array(postgresColumnSchema)),
});
export const postgresMaterializedViewSchema = Type.Object({
    id: Type.Integer(),
    schema: Type.String(),
    name: Type.String(),
    is_populated: Type.Boolean(),
    comment: Type.Union([Type.String(), Type.Null()]),
    columns: Type.Optional(Type.Array(postgresColumnSchema)),
});
export const postgresTablePrivilegesSchema = Type.Object({
    relation_id: Type.Integer(),
    schema: Type.String(),
    name: Type.String(),
    kind: Type.Union([
        Type.Literal('table'),
        Type.Literal('view'),
        Type.Literal('materialized_view'),
        Type.Literal('foreign_table'),
        Type.Literal('partitioned_table'),
    ]),
    privileges: Type.Array(Type.Object({
        grantor: Type.String(),
        grantee: Type.String(),
        privilege_type: Type.Union([
            Type.Literal('SELECT'),
            Type.Literal('INSERT'),
            Type.Literal('UPDATE'),
            Type.Literal('DELETE'),
            Type.Literal('TRUNCATE'),
            Type.Literal('REFERENCES'),
            Type.Literal('TRIGGER'),
            Type.Literal('MAINTAIN'),
        ]),
        is_grantable: Type.Boolean(),
    })),
});
export const postgresTablePrivilegesGrantSchema = Type.Object({
    relation_id: Type.Integer(),
    grantee: Type.String(),
    privilege_type: Type.Union([
        Type.Literal('ALL'),
        Type.Literal('SELECT'),
        Type.Literal('INSERT'),
        Type.Literal('UPDATE'),
        Type.Literal('DELETE'),
        Type.Literal('TRUNCATE'),
        Type.Literal('REFERENCES'),
        Type.Literal('TRIGGER'),
        Type.Literal('MAINTAIN'),
    ]),
    is_grantable: Type.Optional(Type.Boolean()),
});
export const postgresTablePrivilegesRevokeSchema = Type.Object({
    relation_id: Type.Integer(),
    grantee: Type.String(),
    privilege_type: Type.Union([
        Type.Literal('ALL'),
        Type.Literal('SELECT'),
        Type.Literal('INSERT'),
        Type.Literal('UPDATE'),
        Type.Literal('DELETE'),
        Type.Literal('TRUNCATE'),
        Type.Literal('REFERENCES'),
        Type.Literal('TRIGGER'),
        Type.Literal('MAINTAIN'),
    ]),
});
export const postgresColumnPrivilegesSchema = Type.Object({
    column_id: Type.RegExp(/^(\d+)\.(\d+)$/),
    relation_schema: Type.String(),
    relation_name: Type.String(),
    column_name: Type.String(),
    privileges: Type.Array(Type.Object({
        grantor: Type.String(),
        grantee: Type.String(),
        privilege_type: Type.Union([
            Type.Literal('SELECT'),
            Type.Literal('INSERT'),
            Type.Literal('UPDATE'),
            Type.Literal('REFERENCES'),
        ]),
        is_grantable: Type.Boolean(),
    })),
});
export const postgresColumnPrivilegesGrantSchema = Type.Object({
    column_id: Type.RegExp(/^(\d+)\.(\d+)$/),
    grantee: Type.String(),
    privilege_type: Type.Union([
        Type.Literal('ALL'),
        Type.Literal('SELECT'),
        Type.Literal('INSERT'),
        Type.Literal('UPDATE'),
        Type.Literal('REFERENCES'),
    ]),
    is_grantable: Type.Optional(Type.Boolean()),
});
export const postgresColumnPrivilegesRevokeSchema = Type.Object({
    column_id: Type.RegExp(/^(\d+)\.(\d+)$/),
    grantee: Type.String(),
    privilege_type: Type.Union([
        Type.Literal('ALL'),
        Type.Literal('SELECT'),
        Type.Literal('INSERT'),
        Type.Literal('UPDATE'),
        Type.Literal('REFERENCES'),
    ]),
});
//# sourceMappingURL=types.js.map