import { PostgresMeta } from '../../../lib/index.js';
import { createConnectionConfig, extractRequestForLogging } from '../../utils.js';
import { apply as applySwiftTemplate } from '../../templates/swift.js';
import { getGeneratorMetadata } from '../../../lib/generators.js';
export default async (fastify) => {
    fastify.get('/', async (request, reply) => {
        const config = createConnectionConfig(request);
        const excludedSchemas = request.query.excluded_schemas?.split(',').map((schema) => schema.trim()) ?? [];
        const includedSchemas = request.query.included_schemas?.split(',').map((schema) => schema.trim()) ?? [];
        const accessControl = request.query.access_control ?? 'internal';
        const pgMeta = new PostgresMeta(config);
        const { data: generatorMeta, error: generatorMetaError } = await getGeneratorMetadata(pgMeta, {
            includedSchemas,
            excludedSchemas,
        });
        if (generatorMetaError) {
            request.log.error({ error: generatorMetaError, request: extractRequestForLogging(request) });
            reply.code(500);
            return { error: generatorMetaError.message };
        }
        return applySwiftTemplate({
            ...generatorMeta,
            accessControl,
        });
    });
};
//# sourceMappingURL=swift.js.map